==> nextcloud-app-spreed-4.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/he.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "אימות אישור SSL",
    "Delete server" : "מחיקת שרת",
    "Add new server" : "הוספת שרת חדש",
    "Saved" : "נשמר",
    "STUN server URL" : "כתובת שרת STUN",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "מחקת את כל שרתי ה־STUN. כיוון ששרת זה נחוץ כמעט תמיד, נוסף שרת STUN כבררת מחדל.",
    "TURN server URL" : "כתובת שרת TURN",
    "Shared secret" : "סוד משותף",
    "TURN server shared secret" : "סוד משותף לשרת TURN",
    "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
    "UDP and TCP" : "UDP ו־TCP",
    "UDP only" : "UDP בלבד",
    "TCP only" : "TCP בלבד",
    "New public conversation" : "דיון ציבורי חדש",
    "New group conversation" : "דיון קבוצתי חדש",
    "New conversation …" : "דיון חדש…",
    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
    "Screensharing options" : "אפשרויות שיתוף מסך",
    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
    "Participants" : "משתתפים",
    "Chat" : "צ׳אט",
    "Talk" : "שיחה",
    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
    "Fullscreen (f)" : "מסך מלא (f)",
    "Mute audio (m)" : "השתקת שמע (m)",
    "Unmute audio (m)" : "ביטול השקת שמע (m)",
    "No audio" : "אין שמע",
    "Disable video (v)" : "השבתת וידאו (v)",
    "Enable video (v)" : "הפעלת וידאו (v)",
    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
    "No Camera" : "אין מצלמה",
    "Enable screensharing" : "הפעלת שיתוף מסך",
    "Copy" : "העתקה",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
    "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
    "This conversation has ended" : "הדיון הסתיים",
    "Request password" : "בקשת ססמה",
    "Share screen" : "שיתוף המסך",
    "Show your screen" : "הצגת המסך שלך",
    "Stop screensharing" : "הפסקת שיתוף המסך",
    "Error requesting the password." : "בקשת הססמה נכשלה.",
    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
    "Password required" : "נדרשת ססמה",
    "Password" : "ססמה",
    "Cancel" : "ביטול",
    "Submit" : "שליחה",
    "Leave call" : "יציאה מהשיחה",
    "Join call" : "הצטרפות לשיחה",
    "Start call" : "התחלת שיחה",
    "Share link" : "שיתוף קישור",
    "Change password" : "החלפת ססמה",
    "Set password" : "הגדרת ססמה",
    "Name" : "שם",
    "Conversation name" : "שם דיון",
    "Rename" : "שינוי שם",
    "Copy link" : "העתקת קישור",
    "Conversation with {name}" : "דיון עם {name}",
    "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
    "Link copied!" : "קישור הועתק!",
    "You" : "אני",
    "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
    "New message …" : "הודעה חדשה…",
    "Send" : "שליחה",
    "Guest" : "אורח/ת",
    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
    "Today" : "היום",
    "Yesterday" : "מחר",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
    "Edit" : "עריכה",
    "moderator" : "מפקח/ת",
    "Demote from moderator" : "הורדה מדרגת פיקוח",
    "Promote to moderator" : "קידום לדרגת פיקוח",
    "Remove participant" : "הסרת משתתף",
    "Add participant …" : "הוספת משתתף…",
    "Favorited" : "סומן כמועדף",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Leave conversation" : "יציאה מהדיון",
    "Delete conversation" : "מחיקת דיון",
    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
    "Close" : "סגירה",
    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
    "Disable video" : "השבתת וידאו",
    "Show screen" : "הצגת מסך",
    "Enable video" : "הפעלת וידאו",
    "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
    "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
    "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
    "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
    "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
    "{participantName}'s screen" : "המסך של {participantName}",
    "Guest's screen" : "המסך של האורח/ת",
    "Your screen" : "המסך שלך",
    "a conversation" : "דיון",
    "(Duration %s)" : "(משך %s)",
    "You attended a call with {user1}" : "הצטרפת לשיחה עם {user1}",
    "_%n guest_::_%n guests_" : ["אורח/ת 1","%n אורחים","%n אורחים","%n אורחים"],
    "You attended a call with {user1} and {user2}" : "השתתפת בשיחה עם {user1} ועם {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
    "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
    "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
    "Password request by %s" : "בקשת ססמה מאת %s",
    "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
    "%s invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי %s",
    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
    "%s invited you to a group conversation: %s" : "הוזמנת על ידי %s לדיון קבוצתי: %s",
    "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
    "%s invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי %s",
    "{user} invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי {user}",
    "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
    "A group call has started" : "החלה שיחה קבוצתית",
    "{email} requested the password to access a share" : "התקבלה בקשה לססמת גישה לשיתוף על ידי {email}",
    "Video & audio-conferencing using WebRTC" : "דיון עם קול ותמונה באמצעות WebRTC",
    "This call is password-protected" : "שיחה זו מוגנת בססמה",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "Signaling server" : "שרת איתות",
    "STUN servers" : "שרתי STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
    "TURN server" : "שרת TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "Video calls" : "שיחות וידאו",
    "(group)" : "(קבוצה)",
    "New public call" : "שיחה ציבורית חדשה",
    "Looking great today! :)" : "ואו! פשוט יפה! :)",
    "Time to call your friends" : "הגיע הזמן להתקשר לחבריך",
    "You can set your name on the top right of this page so other participants can identify you better." : "באפשרותך להגדיר את השם שלך בפינה השמאלית העליונה של העמוד הזה כדי שמשתתפים אחרים יוכלו לזהות אותך ביתר קלות.",
    "This call has ended" : "השיחה הזאת הסתיימה",
    "Saving failed" : "השמירה נכשלה",
    "Add person" : "הוספת מישהו",
    "and you" : "ואני",
    "Please adjust your configuration" : "נא להתאים את ההגדרות שלך",
    "{actor} invited you to a private call" : "הוזמנת לשיחה פרטית על ידי {actor}",
    "{actor} invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי {actor}",
    "{actor} invited you to the call {call}" : "הוזמנת לשיחה {actor} על ידי {call}",
    "You were invited to a <strong>video call</strong>" : "קיבלת הזמנה ל<strong>שיחת וידאו</strong>",
    "Video call" : "שיחת וידאו",
    "Invalid format, must be stunserver:port." : "תבנית שגויה, חייבת להיות stunserver:port.",
    "Invalid port specified." : "הפתחה שצוינה שגויה.",
    "Invalid protocols specified." : "הפרוטוקולים שצוינו שגויים.",
    "%s invited you to a private call" : "הוזמנת לשיחה פרטית על ידי %s",
    "{user} invited you to a private call" : "הוזמנת לשיחה פרטית על ידי {user}",
    "%s invited you to a group call: %s" : "הוזמנת לשיחה קבוצתית על ידי %s‏: %s",
    "{user} invited you to a group call: {call}" : "הוזמנת לשיחה קבוצתית על ידי {user}:‏ {call}",
    "%s invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי %s",
    "{user} invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי {user}",
    "Fullscreen" : "מסך מלא",
    "Mute audio" : "השתקת שמע",
    "Smile in 3… 2… 1!" : "לחייך בעוד 3… 2… 1!",
    "Choose person …" : "בחירת משתתף …",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "שרת ה־STUN נחוץ כדי שמשתמשים יוכלו להתחבר לשיחות. שרת ה־TURN דואג שהחיבור יעבור גם דרך חומות אש.",
    "STUN server" : "שרת STUN",
    "The STUN server is used to determine the public IP address of participants behind a router." : "שרת ה־STUN משמש לאיתור כתובות ה־IP הציבורית של משתתפים שנמצאים מאחורי נתב."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-app-spreed-4.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/he.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "אימות אישור SSL",
    "Delete server" : "מחיקת שרת",
    "Add new server" : "הוספת שרת חדש",
    "Saved" : "נשמר",
    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "מחקת את כל שרתי ה־STUN. כיוון ששרת זה נחוץ כמעט תמיד, נוסף שרת STUN כבררת מחדל.",
    "STUN server URL" : "כתובת שרת STUN",
    "TURN server URL" : "כתובת שרת TURN",
    "Shared secret" : "סוד משותף",
    "TURN server shared secret" : "סוד משותף לשרת TURN",
    "UDP and TCP" : "UDP ו־TCP",
    "UDP only" : "UDP בלבד",
    "TCP only" : "TCP בלבד",
    "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
    "New public conversation" : "דיון ציבורי חדש",
    "New group conversation" : "דיון קבוצתי חדש",
    "New conversation …" : "דיון חדש…",
    "Screensharing is not supported by your browser." : "בדפדפן שלך אין תמיכה בשיתוף מסך.",
    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
    "Screensharing options" : "אפשרויות שיתוף מסך",
    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
    "Participants" : "משתתפים",
    "Chat" : "צ׳אט",
    "Talk" : "שיחה",
    "Waiting for {participantName} to join the call …" : "בהמתנה להצטרפות לשיחה מצד {participantName}…",
    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
    "Fullscreen (f)" : "מסך מלא (f)",
    "Mute audio (m)" : "השתקת שמע (m)",
    "Unmute audio (m)" : "ביטול השקת שמע (m)",
    "No audio" : "אין שמע",
    "Disable video (v)" : "השבתת וידאו (v)",
    "Enable video (v)" : "הפעלת וידאו (v)",
    "Set your name in the chat window so other participants can identify you better." : "ניתן להגדיר את שמך בחלון הצ׳אט כדי שמשתתפים אחרים יוכלו לזהות אותך בצורה נוחה יותר.",
    "No Camera" : "אין מצלמה",
    "Enable screensharing" : "הפעלת שיתוף מסך",
    "Copy" : "העתקה",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "להעתקה יש ללחוץ ‎⌘-C.",
    "Press Ctrl-C to copy." : "להעתקה יש ללחוץ Ctrl-C.",
    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
    "This conversation has ended" : "הדיון הסתיים",
    "Request password" : "בקשת ססמה",
    "Share screen" : "שיתוף המסך",
    "Show your screen" : "הצגת המסך שלך",
    "Stop screensharing" : "הפסקת שיתוף המסך",
    "Error requesting the password." : "בקשת הססמה נכשלה.",
    "Please enter the password for this call" : "נא להקליד את הססמה של השיחה הזאת",
    "Password required" : "נדרשת ססמה",
    "Password" : "ססמה",
    "Cancel" : "ביטול",
    "Submit" : "שליחה",
    "Leave call" : "יציאה מהשיחה",
    "Join call" : "הצטרפות לשיחה",
    "Start call" : "התחלת שיחה",
    "Share link" : "שיתוף קישור",
    "Change password" : "החלפת ססמה",
    "Set password" : "הגדרת ססמה",
    "Name" : "שם",
    "Conversation name" : "שם דיון",
    "Rename" : "שינוי שם",
    "Copy link" : "העתקת קישור",
    "Conversation with {name}" : "דיון עם {name}",
    "Error occurred while setting password" : "אירעה שגיאה בעת הגדרת ססמה",
    "Link copied!" : "קישור הועתק!",
    "You" : "אני",
    "No messages yet, start the conversation!" : "אין הודעות עדיין, ניתן להתחיל בדיון!",
    "New message …" : "הודעה חדשה…",
    "Send" : "שליחה",
    "Guest" : "אורח/ת",
    "[Unknown user name]" : "[שם המשתמש לא ידוע]",
    "Today" : "היום",
    "Yesterday" : "מחר",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "אירעה שגיאה בעת שליחת ההודעה",
    "Edit" : "עריכה",
    "moderator" : "מפקח/ת",
    "Demote from moderator" : "הורדה מדרגת פיקוח",
    "Promote to moderator" : "קידום לדרגת פיקוח",
    "Remove participant" : "הסרת משתתף",
    "Add participant …" : "הוספת משתתף…",
    "Favorited" : "סומן כמועדף",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Leave conversation" : "יציאה מהדיון",
    "Delete conversation" : "מחיקת דיון",
    "No other people in this call" : "אין אנשים נוספים בשיחה הזאת",
    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
    "Close" : "סגירה",
    "Waiting for camera and microphone permissions" : "בהמתנה להרשאות גישה למצלמה ולמיקרופון",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "נא להעניק לדפדפן שלך גישה להשתמש במצלמה ובמיקרופון שלך כדי להשתמש ביישומון הזה.",
    "Disable video" : "השבתת וידאו",
    "Show screen" : "הצגת מסך",
    "Enable video" : "הפעלת וידאו",
    "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
    "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
    "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
    "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
    "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
    "WebRTC is not supported in your browser :-/" : "בדפדפן שלך אין תמיכה ב־WebRTC :-/",
    "{participantName}'s screen" : "המסך של {participantName}",
    "Guest's screen" : "המסך של האורח/ת",
    "Your screen" : "המסך שלך",
    "a conversation" : "דיון",
    "(Duration %s)" : "(משך %s)",
    "You attended a call with {user1}" : "הצטרפת לשיחה עם {user1}",
    "_%n guest_::_%n guests_" : ["אורח/ת 1","%n אורחים","%n אורחים","%n אורחים"],
    "You attended a call with {user1} and {user2}" : "השתתפת בשיחה עם {user1} ועם {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
    "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
    "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
    "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
    "%s invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי %s",
    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
    "%s invited you to a group conversation: %s" : "הוזמנת על ידי %s לדיון קבוצתי: %s",
    "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
    "%s invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי %s",
    "{user} invited you to a group conversation" : "הוזמנת לדיון קבוצתי על ידי {user}",
    "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
    "A group call has started" : "החלה שיחה קבוצתית",
    "Video & audio-conferencing using WebRTC" : "דיון עם קול ותמונה באמצעות WebRTC",
    "This call is password-protected" : "שיחה זו מוגנת בססמה",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "Signaling server" : "שרת איתות",
    "STUN servers" : "שרתי STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
    "TURN server" : "שרת TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
    "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "Video calls" : "שיחות וידאו",
    "(group)" : "(קבוצה)",
    "New public call" : "שיחה ציבורית חדשה",
    "Looking great today! :)" : "ואו! פשוט יפה! :)",
    "Time to call your friends" : "הגיע הזמן להתקשר לחבריך",
    "You can set your name on the top right of this page so other participants can identify you better." : "באפשרותך להגדיר את השם שלך בפינה השמאלית העליונה של העמוד הזה כדי שמשתתפים אחרים יוכלו לזהות אותך ביתר קלות.",
    "This call has ended" : "השיחה הזאת הסתיימה",
    "Saving failed" : "השמירה נכשלה",
    "Add person" : "הוספת מישהו",
    "and you" : "ואני",
    "Please adjust your configuration" : "נא להתאים את ההגדרות שלך",
    "{actor} invited you to a private call" : "הוזמנת לשיחה פרטית על ידי {actor}",
    "{actor} invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי {actor}",
    "{actor} invited you to the call {call}" : "הוזמנת לשיחה {actor} על ידי {call}",
    "You were invited to a <strong>video call</strong>" : "קיבלת הזמנה ל<strong>שיחת וידאו</strong>",
    "Video call" : "שיחת וידאו",
    "Invalid format, must be stunserver:port." : "תבנית שגויה, חייבת להיות stunserver:port.",
    "Invalid port specified." : "הפתחה שצוינה שגויה.",
    "Invalid protocols specified." : "הפרוטוקולים שצוינו שגויים.",
    "%s invited you to a private call" : "הוזמנת לשיחה פרטית על ידי %s",
    "{user} invited you to a private call" : "הוזמנת לשיחה פרטית על ידי {user}",
    "%s invited you to a group call: %s" : "הוזמנת לשיחה קבוצתית על ידי %s‏: %s",
    "{user} invited you to a group call: {call}" : "הוזמנת לשיחה קבוצתית על ידי {user}:‏ {call}",
    "%s invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי %s",
    "{user} invited you to a group call" : "הוזמנת לשיחה קבוצתית על ידי {user}",
    "Fullscreen" : "מסך מלא",
    "Mute audio" : "השתקת שמע",
    "Smile in 3… 2… 1!" : "לחייך בעוד 3… 2… 1!",
    "Choose person …" : "בחירת משתתף …",
    "The STUN server is necessary so participants can connect to calls. The TURN server makes sure connection works even through firewalls." : "שרת ה־STUN נחוץ כדי שמשתמשים יוכלו להתחבר לשיחות. שרת ה־TURN דואג שהחיבור יעבור גם דרך חומות אש.",
    "STUN server" : "שרת STUN",
    "The STUN server is used to determine the public IP address of participants behind a router." : "שרת ה־STUN משמש לאיתור כתובות ה־IP הציבורית של משתתפים שנמצאים מאחורי נתב.",
    "Password request by %s" : "בקשת ססמה מאת %s",
    "{email} requested the password to access a share" : "התקבלה בקשה לססמת גישה לשיתוף על ידי {email}"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
